Index: src/arm/codegen-arm.h |
=================================================================== |
--- src/arm/codegen-arm.h (revision 4085) |
+++ src/arm/codegen-arm.h (working copy) |
@@ -197,6 +197,10 @@ |
static const int kUnknownIntValue = -1; |
+ // If the name is an inline runtime function call return the number of |
+ // expected arguments. Otherwise return -1. |
+ static int InlineRuntimeCallArgumentsCount(Handle<String> name); |
+ |
private: |
// Construction/Destruction |
explicit CodeGenerator(MacroAssembler* masm); |
@@ -326,6 +330,7 @@ |
struct InlineRuntimeLUT { |
void (CodeGenerator::*method)(ZoneList<Expression*>*); |
const char* name; |
+ int nargs; |
}; |
static InlineRuntimeLUT* FindInlineRuntimeLUT(Handle<String> name); |
@@ -360,7 +365,7 @@ |
// Support for arguments.length and arguments[?]. |
void GenerateArgumentsLength(ZoneList<Expression*>* args); |
- void GenerateArgumentsAccess(ZoneList<Expression*>* args); |
+ void GenerateArguments(ZoneList<Expression*>* args); |
// Support for accessing the class and value fields of an object. |
void GenerateClassOf(ZoneList<Expression*>* args); |
@@ -396,14 +401,10 @@ |
// Fast support for number to string. |
void GenerateNumberToString(ZoneList<Expression*>* args); |
// Fast support for Math.pow(). |
void GenerateMathPow(ZoneList<Expression*>* args); |
- |
- // Fast call to sine function. |
void GenerateMathSin(ZoneList<Expression*>* args); |
void GenerateMathCos(ZoneList<Expression*>* args); |
- |
- // Fast support for Math.pow(). |
void GenerateMathSqrt(ZoneList<Expression*>* args); |
// Simple condition analysis. |
@@ -396,14 +401,10 @@ |
// Fast support for number to string. |
void GenerateNumberToString(ZoneList<Expression*>* args); |
- // Fast support for Math.pow(). |
+ // Fast call to math functions. |
void GenerateMathPow(ZoneList<Expression*>* args); |